@@ -146,16 +146,23 @@ class getter_seleniumTest(baseGetter):
                     銘柄コード
             """
             
+            print('element_count={}'.format(len(element)))
+            
             # getterインスタンス取得
             bc:getter_seleniumTest = kwargs.get('getter')
 
             # 銘柄コード取得
             brandCd = kwargs.get('brandCd')
+            print(brandCd)
             
             # html解析
-            html = self.wDriver.page_source.encode('utf-8')
-            bsSrc = BeautifulSoup(html, 'html.parser')
-
+            #html = self.wDriver.page_source.encode('utf-8')
+            html = element[0].parent.page_source
+            #bsSrc = BeautifulSoup(html, 'html.parser')
+            bsSrc = BeautifulSoup(html, 'lxml')
+            
+            print(html)
+            
             # スクレイピング結果から改行ｺｰﾄﾞを除去
             [tag.extract() for tag in bsSrc(string='\n')]
 
@@ -168,7 +175,9 @@ class getter_seleniumTest(baseGetter):
             if rankingTables:
                 
                 # 戻り値を返す
-                return rsTrnDayStockPrice.getDataFrame()
+                df = rsTrnDayStockPrice.getDataFrame()
+                print('brandcd={} count={}'.format(brandCd),len(df))
+                return df
 
     class beautifulSoup(browserContainer.beautifulSoup):
         
